@@ -147,6 +147,37 @@ as.chron.Date <- function(x, ...)
     chron(unclass(x), ...)
 }
 
+asChronYearFreq <- function(x, frac = 0, holidays = FALSE, frequency, ...) {
+    stopifnot(isTRUE((12 / frequency) %% 1 == 0))
+    x <- unclass(x)
+    year <- floor(x + 0.001)
+    month <- floor(12 * (x - year) + 1 + 0.5 + 0.001)
+    dd.start <- as.Date(paste(year, month, 1, sep = "-"))
+    nd <- 32 * 12 / frequency 
+    dd.end <- dd.start + nd - as.numeric(format(dd.start + nd, "%d"))
+    if (identical(holidays, FALSE))
+      chron(((1 - frac) * as.numeric(dd.start) + frac * as.numeric(dd.end)), ...)
+    else
+      chron(sapply(seq_along(x), function(i) {
+         s <- unclass(seq(dd.start[i], dd.end[i], by = "days"))
+	 h <- if (isTRUE(holidays)) is.holiday(s) else is.holiday(s, holidays)
+         ss <- s[!is.weekend(s) & !h]
+         quantile(ss, probs = frac, names = FALSE)
+     }), ...)
+}
+
+as.chron.yearmon <- function(x, frac = 0, holidays = FALSE, ...) {
+	asChronYearFreq(x, frac = frac, holidays = holidays, frequency = 12, ...)
+}
+
+as.chron.yearqtr <- function(x, frac = 0, holidays = FALSE, ...) {
+	asChronYearFreq(x, frac = frac, holidays = holidays, frequency = 4, ...)
+}
+
+as.chron.ts <- function(x, frac = 0, holidays = FALSE, ...) {
+	asChronYearFreq(time(x), frac = frac, holidays = holidays, frequency = frequency(x), ...)
+}
+
 as.chron.factor <- function(x, ...) 
 {
     as.chron(as.character(x), ...)
